@@ -1,18 +1,16 @@
-# Copyright (c) 2013, Sascha Peilicke <saschpe@gmx.de>
+# Copyright 2013 Sascha Peilicke
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with this program (see the file COPYING); if not, write to the
-# Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import os
 import site
@@ -47,9 +45,9 @@ class Plugin(object):
            >>> import rapport.plugin
            >>> c = rapport.plugin.Plugin(alias="a", url="http://example.com", login="u")
            >>> c._results()
-           {'url': 'http://example.com', 'alias': 'a', 'login': 'u'}
+           {'url': ParseResult(scheme='http', netloc='example.com', path='', params='', query='', fragment=''), 'alias': 'a', 'login': 'u', 'plugin': 'plugin'}
            >>> c._results({'mykey': 'mykey'})
-           {'url': 'http://example.com', 'alias': 'a', 'login': 'u', 'mykey': 'mykey'}
+           {'url': ParseResult(scheme='http', netloc='example.com', path='', params='', query='', fragment=''), 'alias': 'a', 'login': 'u', 'mykey': 'mykey', 'plugin': 'plugin'}
         """
         results = {"plugin": str(self),
                    "alias": self.alias,
@@ -80,7 +78,7 @@ def _get_plugin_dirs():
     plugin_dirs = [
         os.path.expanduser(os.path.join("~", ".rapport", "plugins")),
         os.path.join("rapport", "plugins")  # Local dev tree
-    ]  + map(lambda d: os.path.join(d, "rapport", "plugins"), site.getsitepackages())
+    ] + map(lambda d: os.path.join(d, "rapport", "plugins"), site.getsitepackages())
     return plugin_dirs
 
 
@@ -112,11 +110,22 @@ def discover():
 
     if rapport.config.get_int("rapport", "verbosity") >= 2:
         print "Found plugin modules: {0}".format(plugin_files)
+
+    # Sanitize sys.path. In order to use this code inside a git checkout,
+    # rapport/cli.py does sys.path.append(os.getcwd()). However, we have
+    # rapport modules shadowing system modules (e.g. rapport.email) but some
+    # plugins (notably bugzilla) may have issues with that.
+    old_sys_path = sys.path
+    sys.path = sys.path[2:]
+
     for plugin_file in plugin_files:
         if rapport.config.get_int("rapport", "verbosity") >= 2:
             print "Importing module {0}".format(_path_to_module(plugin_file))
         __import__(_path_to_module(plugin_file))
 
+    # Restore sys.path
+    sys.path = old_sys_path
+
 
 _PLUGIN_CATALOG = {}
 
